import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/common/buttons/search_reset_buttons.dart';
import 'package:syncrow_web/pages/common/text_field/custom_text_field.dart';
import 'package:syncrow_web/pages/device_managment/all_devices/bloc/device_mgmt_bloc/device_managment_bloc.dart';
import 'package:syncrow_web/utils/helpers/responsice_layout_helper/responsive_layout_helper.dart';

class DeviceSearchFilters extends StatefulWidget {
  const DeviceSearchFilters({super.key});

  @override
  State<DeviceSearchFilters> createState() => _DeviceSearchFiltersState();
}

class _DeviceSearchFiltersState extends State<DeviceSearchFilters>
    with HelperResponsiveLayout {
  final _unitNameController = TextEditingController();
  final _productNameController = TextEditingController();

  List<Widget> get _widgets => [
        _buildSearchField("Space Name", _unitNameController, 200),
        _buildSearchField("Device Name / Product Name", _productNameController, 300),
        _buildSearchResetButtons(),
      ];

  @override
  Widget build(BuildContext context) {
    if (isExtraLargeScreenSize(context)) {
      return Row(
        children: _widgets
            .map((e) => Padding(padding: const EdgeInsets.all(10), child: e))
            .toList(),
      );
    }

    return Wrap(
      spacing: 20,
      runSpacing: 10,
      children: _widgets,
    );
  }

  Widget _buildSearchField(
    String title,
    TextEditingController controller,
    double width,
  ) {
    return StatefulTextField(
      title: title,
      width: width,
      elevation: 2,
      controller: controller,
      onSubmitted: () {
        final searchDevicesEvent = SearchDevices(
          productName: _productNameController.text,
          unitName: _unitNameController.text,
          searchField: true,
        );
        context.read<DeviceManagementBloc>().add(searchDevicesEvent);
      },
      onChanged: (p0) {},
    );
  }

  Widget _buildSearchResetButtons() {
    return SearchResetButtons(
      onSearch: () => context.read<DeviceManagementBloc>().add(
            SearchDevices(
              unitName: _unitNameController.text,
              productName: _productNameController.text,
              searchField: true,
            ),
          ),
      onReset: () {
        _unitNameController.clear();
        _productNameController.clear();
        context.read<DeviceManagementBloc>()
          ..add(ResetFilters())
          ..add(FetchDevices(context));
      },
    );
  }
}
