import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/device_managment/one_gang_switch/bloc/wall_light_switch_bloc.dart';
import 'package:syncrow_web/pages/device_managment/one_gang_switch/bloc/wall_light_switch_event.dart';
import 'package:syncrow_web/pages/device_managment/one_gang_switch/bloc/wall_light_switch_state.dart';
import 'package:syncrow_web/pages/device_managment/one_gang_switch/models/wall_light_status_model.dart';
import 'package:syncrow_web/pages/device_managment/shared/toggle_widget.dart';
import 'package:syncrow_web/utils/helpers/responsice_layout_helper/responsive_layout_helper.dart';

class WallLightDeviceControl extends StatelessWidget
    with HelperResponsiveLayout {
  final String deviceId;

  const WallLightDeviceControl({super.key, required this.deviceId});
  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (context) => WallLightSwitchBloc(deviceId: deviceId)
        ..add(WallLightSwitchFetchDeviceEvent(deviceId)),
      child: BlocBuilder<WallLightSwitchBloc, WallLightSwitchState>(
        builder: (context, state) {
          if (state is WallLightSwitchLoading) {
            return const Center(child: CircularProgressIndicator());
          } else if (state is WallLightSwitchStatusLoaded) {
            return _buildStatusControls(context, state.status);
          } else if (state is WallLightSwitchError ||
              state is WallLightSwitchControlError) {
            return const Center(child: Text('Error fetching status'));
          } else {
            return const Center(child: CircularProgressIndicator());
          }
        },
      ),
    );
  }

  Widget _buildStatusControls(
      BuildContext context, WallLightStatusModel status) {
    final isExtraLarge = isExtraLargeScreenSize(context);
    final isLarge = isLargeScreenSize(context);
    final isMedium = isMediumScreenSize(context);
    return GridView(
      padding: const EdgeInsets.symmetric(horizontal: 50),
      shrinkWrap: true,
      physics: const NeverScrollableScrollPhysics(),
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisCount: isLarge || isExtraLarge
            ? 3
            : isMedium
                ? 2
                : 1,
        mainAxisExtent: 140,
        crossAxisSpacing: 12,
        mainAxisSpacing: 12,
      ),
      children: [
        const SizedBox(),
        ToggleWidget(
          value: status.switch1,
          code: 'switch_1',
          deviceId: deviceId,
          label: 'Wall Light',
          onChange: (value) {
            context.read<WallLightSwitchBloc>().add(WallLightSwitchControl(
                  deviceId: deviceId,
                  code: 'switch_1',
                  value: value,
                ));
          },
        ),
        const SizedBox(),
      ],
    );
  }
}
