import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/device_managment/shared/toggle_widget.dart';
import 'package:syncrow_web/pages/device_managment/three_g_glass_switch/bloc/three_gang_glass_switch_bloc.dart';
import 'package:syncrow_web/utils/constants/assets.dart';
import 'package:syncrow_web/utils/helpers/responsice_layout_helper/responsive_layout_helper.dart';

import '../models/three_gang_glass_switch.dart';

class ThreeGangGlassSwitchControlView extends StatelessWidget with HelperResponsiveLayout {
  final String deviceId;

  const ThreeGangGlassSwitchControlView({required this.deviceId, super.key});

  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (context) =>
          ThreeGangGlassSwitchBloc(deviceId: deviceId)..add(ThreeGangGlassSwitchFetchDeviceEvent(deviceId)),
      child: BlocBuilder<ThreeGangGlassSwitchBloc, ThreeGangGlassSwitchState>(
        builder: (context, state) {
          if (state is ThreeGangGlassSwitchLoading) {
            return const Center(child: CircularProgressIndicator());
          } else if (state is ThreeGangGlassSwitchStatusLoaded) {
            return _buildStatusControls(context, state.status);
          } else if (state is ThreeGangGlassSwitchError) {
            return const Center(child: Text('Error fetching status'));
          } else {
            return const Center(child: CircularProgressIndicator());
          }
        },
      ),
    );
  }

  Widget _buildStatusControls(BuildContext context, ThreeGangGlassStatusModel status) {
    final isExtraLarge = isExtraLargeScreenSize(context);
    final isLarge = isLargeScreenSize(context);
    final isMedium = isMediumScreenSize(context);
    return GridView(
      padding: const EdgeInsets.symmetric(horizontal: 50),
      shrinkWrap: true,
      physics: const NeverScrollableScrollPhysics(),
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisCount: isLarge || isExtraLarge
            ? 3
            : isMedium
                ? 2
                : 1,
        mainAxisExtent: 140,
        crossAxisSpacing: 12,
        mainAxisSpacing: 12,
      ),
      children: [
        ToggleWidget(
          value: status.switch1,
          code: 'switch_1',
          deviceId: deviceId,
          label: "Wall Light",
          onChange: (value) {
            context.read<ThreeGangGlassSwitchBloc>().add(
                  ThreeGangGlassSwitchControl(
                    deviceId: deviceId,
                    code: 'switch_1',
                    value: value,
                  ),
                );
          },
        ),
        ToggleWidget(
          value: status.switch2,
          code: 'switch_2',
          deviceId: deviceId,
          label: "Ceiling Light",
          onChange: (value) {
            context.read<ThreeGangGlassSwitchBloc>().add(
                  ThreeGangGlassSwitchControl(
                    deviceId: deviceId,
                    code: 'switch_2',
                    value: value,
                  ),
                );
          },
        ),
        ToggleWidget(
          value: status.switch3,
          code: 'switch_3',
          deviceId: deviceId,
          label: "SpotLight",
          onChange: (value) {
            context.read<ThreeGangGlassSwitchBloc>().add(
                  ThreeGangGlassSwitchControl(
                    deviceId: deviceId,
                    code: 'switch_3',
                    value: value,
                  ),
                );
          },
        ),
        ToggleWidget(
          value: false,
          code: '',
          deviceId: deviceId,
          label: 'Preferences',
          icon: Assets.preferences,
          onChange: (value) {},
          showToggle: false,
        ),
        ToggleWidget(
          value: false,
          code: '',
          deviceId: deviceId,
          label: 'Scheduling',
          icon: Assets.scheduling,
          onChange: (value) {},
          showToggle: false,
        ),
      ],
    );
  }
}
