import 'package:flutter/material.dart';
import 'package:syncrow_web/utils/color_manager.dart';

class DialogFooter extends StatelessWidget {
  final VoidCallback onCancel;
  final VoidCallback? onConfirm;
  final bool isConfirmEnabled;
  final int? dialogWidth;

  const DialogFooter({
    Key? key,
    required this.onCancel,
    required this.onConfirm,
    required this.isConfirmEnabled,
    this.dialogWidth,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: const BoxDecoration(
        border: Border(
          top: BorderSide(
            color: ColorsManager.greyColor,
          ),
        ),
      ),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          Expanded(
            child: _buildFooterButton(
              context,
              'Cancel',
              onCancel,
            ),
          ),
          if (isConfirmEnabled) ...[
            Container(width: 1, height: 50, color: ColorsManager.greyColor),
            Expanded(
              child: _buildFooterButton(
                context,
                'Confirm',
                onConfirm,
              ),
            ),
          ],
        ],
      ),
    );
  }

  Widget _buildFooterButton(
    BuildContext context,
    String text,
    VoidCallback? onTap,
  ) {
    return GestureDetector(
      onTap: onTap,
      child: SizedBox(
        height: 50,
        child: Center(
          child: Text(
            text,
            style: Theme.of(context).textTheme.bodyMedium!.copyWith(
                  color: text == 'Confirm'
                      ? ColorsManager.primaryColorWithOpacity
                      : ColorsManager.textGray,
                ),
          ),
        ),
      ),
    );
  }
}
