import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/routines/bloc/automation_scene_trigger_bloc/automation_status_update.dart';
import 'package:syncrow_web/pages/routines/bloc/routine_bloc/routine_bloc.dart';
import 'package:syncrow_web/pages/routines/widgets/main_routine_view/routine_view_card.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';
import 'package:syncrow_web/utils/helpers/responsice_layout_helper/responsive_layout_helper.dart';

class FetchRoutineScenesAutomation extends StatefulWidget {
  const FetchRoutineScenesAutomation({super.key});

  @override
  State<FetchRoutineScenesAutomation> createState() =>
      _FetchRoutineScenesState();
}

class _FetchRoutineScenesState extends State<FetchRoutineScenesAutomation>
    with HelperResponsiveLayout {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<RoutineBloc, RoutineState>(
      builder: (context, state) {
        return state.isLoading
            ? const Center(
                child: CircularProgressIndicator(),
              )
            : SingleChildScrollView(
                child: Padding(
                  padding: const EdgeInsets.symmetric(vertical: 16.0),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      Text(
                        "Scenes (Tab to Run)",
                        style: Theme.of(context).textTheme.titleLarge?.copyWith(
                              color: ColorsManager.grayColor,
                              fontWeight: FontWeight.bold,
                            ),
                      ),
                      const SizedBox(height: 10),
                      if (state.scenes.isEmpty)
                        Text(
                          "No scenes found",
                          style: context.textTheme.bodyMedium?.copyWith(
                            color: ColorsManager.grayColor,
                          ),
                        ),
                      if (state.scenes.isNotEmpty)
                        SizedBox(
                          height: 200, 
                          child: ListView.builder(
                              shrinkWrap: true,
                              scrollDirection: Axis.horizontal,
                              itemCount: state.scenes.length,
                              itemBuilder: (context, index) {
                                final scene = state.scenes[index];
                                final isLoading =
                                    state.loadingSceneId == scene.id;

                                return Padding(
                                  padding: EdgeInsets.only(
                                    right:
                                        isSmallScreenSize(context) ? 4.0 : 8.0,
                                  ),
                                  child: Column(
                                    children: [
                                      RoutineViewCard(
                                        isLoading: isLoading,
                                        sceneOnTap: () {
                                          context.read<RoutineBloc>().add(
                                              SceneTrigger(
                                                  sceneId: scene.id,
                                                  name: scene.name));
                                        },
                                        status: state.scenes[index].status,
                                        communityId:
                                            state.scenes[index].communityId ??
                                                '',
                                        spaceId: state.scenes[index].spaceId,
                                        sceneId:
                                            state.scenes[index].sceneTuyaId!,
                                        automationId: state.scenes[index].id,
                                        cardType: 'scenes',
                                        spaceName:
                                            state.scenes[index].spaceName,
                                        onTap: () {
                                          BlocProvider.of<RoutineBloc>(context)
                                              .add(
                                            const CreateNewRoutineViewEvent(
                                                createRoutineView: true),
                                          );
                                          context.read<RoutineBloc>().add(
                                                GetSceneDetails(
                                                  sceneId:
                                                      state.scenes[index].id,
                                                  isTabToRun: true,
                                                  isUpdate: true,
                                                ),
                                              );
                                        },
                                        textString: state.scenes[index].name,
                                        icon: state.scenes[index].icon ??
                                            Assets.logoHorizontal,
                                        isFromScenes: true,
                                        iconInBytes:
                                            state.scenes[index].iconInBytes,
                                      ),
                                    ],
                                  ),
                                );
                              }),
                        ),
                      const SizedBox(height: 10),
                      Text(
                        "Automations",
                        style: Theme.of(context).textTheme.titleLarge?.copyWith(
                              color: ColorsManager.grayColor,
                              fontWeight: FontWeight.bold,
                            ),
                      ),
                      const SizedBox(height: 3),
                      if (state.automations.isEmpty)
                        Text(
                          "No automations found",
                          style: context.textTheme.bodyMedium?.copyWith(
                            color: ColorsManager.grayColor,
                          ),
                        ),
                      if (state.automations.isNotEmpty)
                        SizedBox(
                          height: 200, 

                          child: ListView.builder(
                              shrinkWrap: true,
                              scrollDirection: Axis.horizontal,
                              itemCount: state.automations.length,
                              itemBuilder: (context, index) {
                                final isLoading = state.automations!
                                    .contains(state.automations[index].id);

                                return Column(
                                  children: [
                                    Padding(
                                      padding: EdgeInsets.only(
                                        right: isSmallScreenSize(context)
                                            ? 4.0
                                            : 8.0,
                                      ),
                                      child: RoutineViewCard(
                                        isLoading: isLoading,
                                        onChanged: (v) {
                                          context.read<RoutineBloc>().add(
                                                UpdateAutomationStatus(
                                                  automationId: state
                                                      .automations[index].id,
                                                  automationStatusUpdate:
                                                      AutomationStatusUpdate(
                                                          spaceUuid: state
                                                              .automations[
                                                                  index]
                                                              .spaceId,
                                                          isEnable: v),
                                                  communityId: state
                                                      .automations[index]
                                                      .communityId,
                                                ),
                                              );
                                        },
                                        status: state.automations[index].status,
                                        communityId: '',
                                        spaceId:
                                            state.automations[index].spaceId,
                                        sceneId: '',
                                        automationId:
                                            state.automations[index].id,
                                        cardType: 'automations',
                                        spaceName:
                                            state.automations[index].spaceName,
                                        onTap: () {
                                          BlocProvider.of<RoutineBloc>(context)
                                              .add(
                                            const CreateNewRoutineViewEvent(
                                                createRoutineView: true),
                                          );
                                          context.read<RoutineBloc>().add(
                                                GetAutomationDetails(
                                                    automationId: state
                                                        .automations[index].id,
                                                    isAutomation: true,
                                                    isUpdate: true),
                                              );
                                        },
                                        textString:
                                            state.automations[index].name,
                                        icon: state.automations[index].icon ??
                                            Assets.automation,
                                      ),
                                    ),
                                  ],
                                );
                              }),
                        ),
                    ],
                  ),
                ),
              );
      },
    );
  }
}
