import 'package:flutter/material.dart';
import 'package:syncrow_web/utils/color_manager.dart';

class CustomExpansionTileSpaceTree extends StatelessWidget {
  final String? spaceId;
  final String title;
  final List<Widget>? children;
  final bool isSelected;
  final bool isSoldCheck;
  final bool isExpanded;
  final Function? onExpansionChanged;
  final Function? onItemSelected;

  const CustomExpansionTileSpaceTree(
      {super.key,
      this.spaceId,
      required this.title,
      this.children,
      this.isExpanded = false,
      this.onExpansionChanged,
      this.onItemSelected,
      required this.isSelected,
      this.isSoldCheck = false});

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Row(
          children: [
            Checkbox(
              value: isSoldCheck ? null : isSelected,
              onChanged: (bool? value) {
                if (onItemSelected != null) {
                  onItemSelected!();
                }
              },
              tristate: true,
              side: WidgetStateBorderSide.resolveWith((states) {
                return const BorderSide(color: ColorsManager.grayBorder);
              }),
              fillColor: WidgetStateProperty.resolveWith((states) {
                if (states.contains(WidgetState.selected)) {
                  return ColorsManager.blue1;
                } else {
                  return ColorsManager.checkBoxFillColor;
                }
              }),
              checkColor: ColorsManager.whiteColors,
            ),
            if (children != null && children!.isNotEmpty)
              InkWell(
                onTap: () {
                  if (onExpansionChanged != null) {
                    onExpansionChanged!();
                  }
                },
                child: Icon(
                  isExpanded ? Icons.keyboard_arrow_down : Icons.keyboard_arrow_right,
                  color: ColorsManager.lightGrayColor,
                  size: 16.0,
                ),
              ),
            Expanded(
              child: GestureDetector(
                onTap: () {
                  if (onItemSelected != null) {
                    onItemSelected!();
                  }
                },
                child: Text(
                  _capitalizeFirstLetter(title),
                  style: Theme.of(context).textTheme.bodySmall!.copyWith(
                        color: isSelected
                            ? ColorsManager.blackColor // Change color to black when selected
                            : ColorsManager.lightGrayColor, // Gray when not selected
                        fontWeight: FontWeight.w400,
                      ),
                ),
              ),
            ),
          ],
        ),
        if (isExpanded && children != null && children!.isNotEmpty)
          Padding(
            padding: const EdgeInsets.only(left: 24.0),
            child: Column(
              children: children ?? [],
            ),
          ),
      ],
    );
  }

  String _capitalizeFirstLetter(String text) {
    if (text.isEmpty) return text;
    return text[0].toUpperCase() + text.substring(1);
  }
}
