import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:syncrow_web/common/edit_chip.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/model/product_model.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/model/tag.dart';
import 'package:syncrow_web/pages/spaces_management/assign_tag_models/views/assign_tag_models_dialog.dart';
import 'package:syncrow_web/pages/spaces_management/helper/tag_helper.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/models/space_template_model.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/models/subspace_template_model.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/widgets/button_content_widget.dart';
import 'package:syncrow_web/pages/spaces_management/tag_model/views/add_device_type_model_widget.dart';
import 'package:syncrow_web/utils/color_manager.dart';

class TagChipDisplay extends StatelessWidget {
  final double screenWidth;
  final SpaceTemplateModel? spaceModel;
  final List<ProductModel>? products;
  final List<SubspaceTemplateModel>? subspaces;
  final List<String>? allTags;
  final TextEditingController spaceNameController;
  final BuildContext? pageContext;
  final List<String>? otherSpaceModels;
  final List<SpaceTemplateModel>? allSpaceModels;
  final List<Tag> projectTags;

  const TagChipDisplay(BuildContext context,
      {Key? key,
      required this.screenWidth,
      required this.spaceModel,
      required this.products,
      required this.subspaces,
      required this.allTags,
      required this.spaceNameController,
      this.pageContext,
      this.otherSpaceModels,
      this.allSpaceModels,
      required this.projectTags})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return (spaceModel?.tags?.isNotEmpty == true ||
            spaceModel?.subspaceModels?.any((subspace) => subspace.tags?.isNotEmpty == true) ==
                true)
        ? SizedBox(
            width: screenWidth * 0.25,
            child: Container(
              padding: const EdgeInsets.all(8.0),
              decoration: BoxDecoration(
                color: ColorsManager.textFieldGreyColor,
                borderRadius: BorderRadius.circular(15),
                border: Border.all(
                  color: ColorsManager.textFieldGreyColor,
                  width: 3.0, // Border width
                ),
              ),
              child: Wrap(
                spacing: 8.0,
                runSpacing: 8.0,
                children: [
                  // Combine tags from spaceModel and subspaces
                  ...TagHelper.groupTags([
                    ...?spaceModel?.tags,
                    ...?spaceModel?.subspaceModels?.expand((subspace) => subspace.tags ?? [])
                  ]).entries.map(
                        (entry) => Chip(
                          avatar: SizedBox(
                            width: 24,
                            height: 24,
                            child: SvgPicture.asset(
                              entry.key.icon ?? 'assets/icons/gateway.svg',
                              fit: BoxFit.contain,
                            ),
                          ),
                          label: Text(
                            'x${entry.value}', // Show count
                            style: Theme.of(context)
                                .textTheme
                                .bodySmall!
                                .copyWith(color: ColorsManager.spaceColor),
                          ),
                          backgroundColor: ColorsManager.whiteColors,
                          shape: RoundedRectangleBorder(
                            borderRadius: BorderRadius.circular(16),
                            side: const BorderSide(
                              color: ColorsManager.spaceColor,
                            ),
                          ),
                        ),
                      ),
                  EditChip(onTap: () async {
                    // Use the Navigator's context for showDialog
                    Navigator.of(context).pop();

                    await showDialog<bool>(
                        barrierDismissible: false,
                        context: context,
                        builder: (context) => AssignTagModelsDialog(
                              products: products,
                              allSpaceModels: allSpaceModels,
                              subspaces: subspaces,
                              pageContext: pageContext,
                              allTags: allTags,
                              spaceModel: spaceModel,
                              otherSpaceModels: otherSpaceModels,
                              initialTags: TagHelper.generateInitialTags(
                                  subspaces: subspaces, spaceTagModels: spaceModel?.tags ?? []),
                              title: 'Edit Device',
                              addedProducts: TagHelper.createInitialSelectedProducts(
                                  spaceModel?.tags ?? [], subspaces),
                              spaceName: spaceModel?.modelName ?? '',
                              projectTags: projectTags,
                            ));
                  })
                ],
              ),
            ),
          )
        : TextButton(
            onPressed: () async {
              Navigator.of(context).pop();

              await showDialog<bool>(
                barrierDismissible: false,
                context: context,
                builder: (context) => AddDeviceTypeModelWidget(
                  products: products,
                  subspaces: subspaces,
                  allTags: allTags,
                  spaceName: spaceNameController.text,
                  pageContext: pageContext,
                  isCreate: true,
                  spaceModel: spaceModel,
                  otherSpaceModels: otherSpaceModels,
                  projectTags: projectTags,
                ),
              );
            },
            style: TextButton.styleFrom(
              padding: EdgeInsets.zero,
            ),
            child: const ButtonContentWidget(
              icon: Icons.add,
              label: 'Add Devices',
            ),
          );
  }
}
